@@ -5,19 +5,14 @@
 
 These checks validate that a Splunk app has been correctly packaged, and can be provided safely for package validation.
 """
-
-# Python Standard Library
 import logging
 import os
 import stat
 from functools import wraps
 
-# N/A
-# Custom Libraries
 import splunk_appinspect
 from splunk_appinspect.app_util import AppVersionNumberMatcher
 
-
 report_display_order = 1
 logger = logging.getLogger(__name__)
 
@@ -33,10 +28,9 @@ def app_package_extractable(check):
             check(app, reporter)
         else:
             reporter_output = (
-                "Splunk App package is not a valid compressed file"
-                " and cannot be extracted."
-                " Origin artifact name: {}"
-            ).format(app.package.origin_artifact_name)
+                "Splunk App package is not a valid compressed file and cannot be extracted."
+                f" Origin artifact name: {app.package.origin_artifact_name}"
+            )
             reporter.fail(reporter_output)
 
     return wrap
@@ -46,7 +40,12 @@ def app_package_extractable(check):
 # ORIGIN ARTIFACT CHECKS
 # ------------------------------------------------------------------------------
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
+    "splunk_appinspect",
+    "appapproval",
+    "cloud",
+    "packaging_standards",
+    "self-service",
+    "private_app",
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 @app_package_extractable
@@ -64,23 +63,31 @@ def check_that_splunk_app_package_has_read_permission(app, reporter):
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
+    "splunk_appinspect",
+    "appapproval",
+    "cloud",
+    "packaging_standards",
+    "self-service",
+    "private_app",
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_that_splunk_app_package_valid_compressed_file(app, reporter):
-    """Check that the Splunk app provided a valid compressed file.
-    """
+    """Check that the Splunk app provided a valid compressed file."""
     if not app.package.is_origin_artifact_valid_compressed_file():
         reporter_output = (
-            "Splunk App package is not a valid compressed file"
-            " and cannot be extracted."
-            " Origin artifact name: {}"
-        ).format(app.package.origin_artifact_name)
+            "Splunk App package is not a valid compressed file and cannot be extracted. "
+            f"Origin artifact name: {app.package.origin_artifact_name}"
+        )
         reporter.fail(reporter_output)
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
+    "splunk_appinspect",
+    "appapproval",
+    "cloud",
+    "packaging_standards",
+    "self-service",
+    "private_app",
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_that_splunk_app_package_name_does_not_start_with_period(app, reporter):
@@ -90,16 +97,14 @@ def check_that_splunk_app_package_name_does_not_start_with_period(app, reporter)
     if app.package.does_origin_artifact_start_with_period():
         if app.package.origin_artifact_name.startswith("."):
             reporter_output = (
-                "Splunk App packages cannot start with a `.` as its"
-                " name."
-                " Origin artifact name: {}"
-            ).format(app.package.origin_artifact_name)
+                "Splunk App packages cannot start with a `.` as its name. "
+                f"Origin artifact name: {app.package.origin_artifact_name}"
+            )
         else:
             reporter_output = (
-                "Splunk App packages cannot start with a `.` as its"
-                " name."
-                " Origin package name: {}"
-            ).format(app.package.origin_package_name)
+                "Splunk App packages cannot start with a `.` as its name. "
+                f"Origin package name: {app.package.origin_package_name}"
+            )
         reporter.fail(reporter_output)
 
 
@@ -107,7 +112,12 @@ def check_that_splunk_app_package_name_does_not_start_with_period(app, reporter)
 # WORKING ARTIFACT CHECKS
 # ------------------------------------------------------------------------------
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
+    "splunk_appinspect",
+    "appapproval",
+    "cloud",
+    "packaging_standards",
+    "self-service",
+    "private_app",
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_that_splunk_app_package_extracts_to_visible_directory(app, reporter):
@@ -118,14 +128,19 @@ def check_that_splunk_app_package_extracts_to_visible_directory(app, reporter):
         reporter_output = (
             "Splunk App packages must extract to a directory"
             " that is not hidden. The Splunk App package"
-            " extracted to: {}"
-        ).format(app.package.working_artifact_name)
+            f" extracted to: {app.package.working_artifact_name}"
+        )
 
         reporter.fail(reporter_output)
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
+    "splunk_appinspect",
+    "appapproval",
+    "cloud",
+    "packaging_standards",
+    "self-service",
+    "private_app",
 )
 @splunk_appinspect.cert_version(min="1.5.3")
 @app_package_extractable
@@ -144,7 +159,7 @@ def check_that_splunk_app_package_does_not_contain_files_outside_of_app(app, rep
         else:
             reporter_output = (
                 "A file or folder was found outside of the app"
-                " directory. Please remove this file or folder: {}".format(relative_loc)
+                f" directory. Please remove this file or folder: {relative_loc}"
             )
             reporter.fail(reporter_output)
 
@@ -161,15 +176,18 @@ def check_that_splunk_app_package_does_not_contain_files_outside_of_app(app, rep
         reporter_output = (
             "A file or folder was found outside of the app"
             " within the overall package. OR the file or folder does not have expected permission. "
-            "Please remove this file or folder OR modify the permission : {}".format(
-                file_or_folder_outside_app
-            )
+            f"Please remove this file or folder OR modify the permission : {file_or_folder_outside_app}"
         )
         reporter.fail(reporter_output)
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
+    "splunk_appinspect",
+    "appapproval",
+    "cloud",
+    "packaging_standards",
+    "self-service",
+    "private_app",
 )
 @splunk_appinspect.cert_version(min="1.5.3")
 @app_package_extractable
@@ -182,9 +200,10 @@ def check_that_splunk_app_package_with_static_dependencies_has_exactly_one_app_f
     # If no .dependencies folder exists, return N/A
     if not app.package.does_package_contain_dependencies_folder():
         reporter_output = (
-            "No {} folder found. Please add a .dependencies directory"
-            " with an valid app folder."
-        ).format(app.dependencies_directory_path)
+            f"No {app.dependencies_directory_path} folder found. "
+            "Please add a .dependencies directory with an valid "
+            "app folder."
+        )
         reporter.not_applicable(reporter_output)
         return
 
@@ -205,21 +224,24 @@ def check_that_splunk_app_package_with_static_dependencies_has_exactly_one_app_f
     if (
         len(contents) != 2
         or not all_contents_are_folders
-        or not relative_dependencies_path in contents
-        or not relative_working_app_path in contents
+        or relative_dependencies_path not in contents
+        or relative_working_app_path not in contents
     ):
         reporter_output = (
-            "Only a single app folder and a single {} folder"
-            " should be included for apps packaged with static"
-            " dependencies using the Splunk Packaging Toolkit.".format(
-                app.dependencies_directory_path
-            )
+            f"Only a single app folder and a single {app.dependencies_directory_path} "
+            "folder should be included for apps packaged with static dependencies "
+            "using the Splunk Packaging Toolkit."
         )
         reporter.fail(reporter_output)
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
+    "splunk_appinspect",
+    "appapproval",
+    "cloud",
+    "packaging_standards",
+    "self-service",
+    "private_app",
 )
 @splunk_appinspect.cert_version(min="1.5.3")
 @app_package_extractable
@@ -232,9 +254,10 @@ def check_that_splunk_app_package_with_static_dependencies_has_app_manifest(
     # If no .dependencies folder exists, return N/A
     if not app.package.does_package_contain_dependencies_folder():
         reporter_output = (
-            "No {} folder found. Please add a .dependencies directory"
-            " that contains an app folder with an app.manifest."
-        ).format(app.dependencies_directory_path)
+            f"No {app.dependencies_directory_path} folder found. "
+            "Please add a .dependencies directory that contains "
+            "an app folder with an app.manifest."
+        )
         reporter.not_applicable(reporter_output)
         return
 
@@ -243,17 +266,23 @@ def check_that_splunk_app_package_with_static_dependencies_has_app_manifest(
     # valid when packaged and specified with slim)
     if not app.package.does_working_artifact_contain_app_manifest():
         reporter_output = (
-            "App folder associated with package does not contain"
-            " an app.manifest file but contains a {} directory."
+            "App folder associated with package does not"
+            f" contain an app.manifest file but contains "
+            f" a {app.dependencies_directory_path} directory."
             " Apps packaged with static dependencies using the"
             " Splunk Packaging Toolkit are required to have an"
-            " app.manifest file.".format(app.dependencies_directory_path)
+            " app.manifest file."
         )
         reporter.fail(reporter_output)
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
+    "splunk_appinspect",
+    "appapproval",
+    "cloud",
+    "packaging_standards",
+    "self-service",
+    "private_app",
 )
 @splunk_appinspect.cert_version(min="1.5.3")
 @app_package_extractable
@@ -265,10 +294,9 @@ def check_that_splunk_app_package_has_valid_static_dependencies(app, reporter):
     # If no .dependencies folder exists, return N/A
     if not app.package.does_package_contain_dependencies_folder():
         reporter_output = (
-            "No {} folder found. Please check that the Splunk App "
-            "package contains only valid dependencies.".format(
-                app.dependencies_directory_path
-            )
+            f"No {app.dependencies_directory_path} folder found. "
+            "Please check that the Splunk App "
+            "package contains only valid dependencies."
         )
         reporter.not_applicable(reporter_output)
         return
@@ -290,9 +318,8 @@ def check_that_splunk_app_package_has_valid_static_dependencies(app, reporter):
             reporter_output = (
                 "Resource within the .dependencies folder that"
                 " does not appear to be a valid app package."
-                " Please remove this file or folder: {}/{}".format(
-                    app.dependencies_directory_path, dependency_resource
-                )
+                " Please remove this file or folder: "
+                f" {app.dependencies_directory_path}/{dependency_resource}"
             )
             reporter.fail(reporter_output)
 
@@ -306,7 +333,12 @@ def check_that_splunk_app_package_has_valid_static_dependencies(app, reporter):
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
+    "splunk_appinspect",
+    "appapproval",
+    "cloud",
+    "packaging_standards",
+    "self-service",
+    "private_app",
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 @app_package_extractable
@@ -324,13 +356,18 @@ def check_that_extracted_splunk_app_does_not_contain_prohibited_directories_or_f
         relative_loc = os.path.relpath(prohibited_directory_or_file, app.app_dir)
         reporter_output = (
             "A prohibited file or directory was found in the"
-            " extracted Splunk App: {}"
-        ).format(relative_loc)
+            f" extracted Splunk App: {relative_loc}"
+        )
         reporter.fail(reporter_output)
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
+    "splunk_appinspect",
+    "appapproval",
+    "cloud",
+    "packaging_standards",
+    "self-service",
+    "private_app",
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_that_extracted_splunk_app_contains_default_app_conf_file(app, reporter):
@@ -341,13 +378,18 @@ def check_that_extracted_splunk_app_contains_default_app_conf_file(app, reporter
         reporter_output = (
             "Splunk App packages must contain a"
             " `default/app.conf file`."
-            " No `default/app.conf` was found in `{}`."
-        ).format(app.package.origin_artifact_name)
+            f" No `default/app.conf` was found in `{app.package.origin_artifact_name}`."
+        )
         reporter.fail(reporter_output)
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
+    "splunk_appinspect",
+    "appapproval",
+    "cloud",
+    "packaging_standards",
+    "self-service",
+    "private_app",
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_that_extracted_splunk_app_contains_default_app_conf_file_with_valid_version_number(
@@ -363,8 +405,9 @@ def check_that_extracted_splunk_app_contains_default_app_conf_file_with_valid_ve
         reporter_output = (
             "Splunk App packages must contain a"
             " `default/app.conf file`."
-            " No `default/app.conf` was found in `{}`."
-        ).format(app.package.origin_artifact_name)
+            " No `default/app.conf` was found "
+            f" in `{app.package.origin_artifact_name}`."
+        )
         reporter.fail(reporter_output)
         return
 
@@ -398,7 +441,12 @@ def check_that_extracted_splunk_app_contains_default_app_conf_file_with_valid_ve
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
+    "splunk_appinspect",
+    "appapproval",
+    "cloud",
+    "packaging_standards",
+    "self-service",
+    "private_app",
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 @app_package_extractable
@@ -412,14 +460,17 @@ def check_that_extracted_splunk_app_does_not_contain_invalid_directories(app, re
         app.package.working_artifact, stat.S_IRWXU
     )
     for invalid_directory in invalid_directories:
-        reporter_output = (
-            "An invalid directory was found in the" " extracted Splunk App: {}"
-        ).format(invalid_directory)
+        reporter_output = f"An invalid directory was found in the extracted Splunk App: {invalid_directory}"
         reporter.fail(reporter_output)
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
+    "splunk_appinspect",
+    "appapproval",
+    "cloud",
+    "packaging_standards",
+    "self-service",
+    "private_app",
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 @app_package_extractable
@@ -435,12 +486,14 @@ def check_that_extracted_splunk_app_does_not_contain_files_with_invalid_permissi
     )
     for invalid_file in invalid_files:
         reporter_output = (
-            "An invalid file was found in the" " extracted Splunk App: {}"
-        ).format(invalid_file)
+            f"An invalid file was found in the extracted Splunk App: {invalid_file}"
+        )
         reporter.fail(reporter_output)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "packaging_standards", "private_app")
+@splunk_appinspect.tags(
+    "splunk_appinspect", "cloud", "packaging_standards", "private_app"
+)
 @splunk_appinspect.cert_version(min="1.0.0")
 def check_requires_adobe_flash(app, reporter):
     """Check that the app does not use Adobe Flash files."""
@@ -460,7 +513,7 @@ def check_requires_adobe_flash(app, reporter):
     ]
     if len(flash_files) > 0:
         for flash_file in flash_files:
-            reporter_output = ("Flash file was detected. File: {}").format(flash_file)
+            reporter_output = f"Flash file was detected. File: {flash_file}"
             reporter.fail(reporter_output, flash_file)
     else:
         reporter_output = "Didn't find any flash files."
