@@ -45,7 +45,7 @@ def normalizeBoolean(input_param, enableStrictMode=False, includeIntegers=True):
 
         try:
             test = input_param.strip().lower()
-        except:
+        except Exception:
             return input_param
 
         if test in trueThings:
